--[[
******************************************************************
Script to install the magnetic stripe fonts on the system.

 ***** IMPORTANT NOTE *****
The script to uninstall fonts does not need to be called first. 
If the font is detected on the system it will be unregistered before
the new font file is copied and registered on the system.
******************************************************************
]]--

fDebug("\r\n\Installing magstripe fonts...");
-- Reset the return status string so it contains only text from this script when it returns

local bContinue = true;
local tblFileNames = { "DXP01_T1.ttf", "DXP01_T2.ttf","DXP01_T3.ttf","DXP01_JIS.ttf" };
local tblFontNames = { "Mag Track 1 XPS Card Printer", "Mag Track 2 XPS Card Printer", "Mag Track 3 XPS Card Printer", "Mag Track JIS XPS Card Printer"}

-- ************************************
--   Get Fonts folder path
-- ************************************
local fonts_dir = Shell.GetFolder(SHF_FONTS); -- Gets the path to the user's Font directory.
local error = Application.GetLastError();
if (error ~= 0) then
	fDebug("ERROR: Error detecting system font folder: "..error);
	bContinue = false;
end

if (bContinue) then
	-- Put a loop here to loop through a table of font names and file names so the same code can be reused n times.
	local fontCount = Table.Count(tblFontNames);
	local loopCounter = 1;
	repeat  
		local strFontFileName = tblFileNames[loopCounter];
		local strFontName = tblFontNames[loopCounter];
		--  ************************************
		--  Detect if the font is installed.  If it is, try to unregister it.
		--  This may fail because the file is present but the font is not registered.
		--  If it fails, continue on.
		--  ************************************
		if (File.DoesExist(fonts_dir.."\\"..strFontFileName)) then -- Check if the font exits.  If it does, unregister it.
			System.UnregisterFont(fonts_dir.."\\"..strFontFileName, strFontName, true);
		end
		
		-- ************************************
		-- Copy the font file to the Fonts directory overwriting the file if it is already there.
		-- This may fail if the font is marked 'in use'
		-- If it fails, continue on.
		-- 	************************************
		File.Copy(_SourceFolder.."\\AutoPlay\\Fonts\\"..strFontFileName, fonts_dir.."\\"..strFontFileName, false, true, false, true, nil); -- Copy the magstripe file to the Fonts folder.
		
		-- ************************************
		-- Register the font.
		-- This should not fail.
		-- ************************************
		if (File.DoesExist(fonts_dir.."\\"..strFontFileName)) then
			System.RegisterFont(fonts_dir.."\\"..strFontFileName, strFontName, true); -- Register the font.
			error = Application.GetLastError();
			if (error ~= 0) then
				fDebug("ERROR: Error registering font file: "..strFontFileName..".  Error: "..error);
			else
				fDebug("  Registered magstripe font file: "..strFontFileName.." with name: "..strFontName);
			end
		end
	loopCounter = loopCounter + 1;
	until loopCounter > fontCount
end	


-- Send a signal back to the main script using the bContinueInstall flag.
-- always continue. Don't abort the driver installation because of a font issue.
bContinueInstall = true;
fDebug("COMPLETE: Magstripe fonts installed.");
