	--[[ 
**************************
Fix for Belcarra unistall issue.  Registry settings are not
uninstalled and new settings do not overwrite existing settings.
Need to set these to a known good value.  
Get current registry settings and modify if not correct.  
If modify, request restart.
***************************
]]--
fDebug("\r\n\Checking USBLan registry values...");

local strDatacardUSBLANKeyPath = "SYSTEM\\CURRENTCONTROLSET\\SERVICES\\DataCardUSBLan";
	
-- desired values
local strNdisIfTypeSetValue = "1";
local strSingleInOutSetValue = "0";
local strNetLIPSetValue = "16907945";   -- 0x0101fea9
local strNetMIPSetValue = "4026662569"; -- 0x001fea9
local strNetSIPSetValue = "4261543593"; -- 0xfe01fea9
local strNetMaskSetValue = "16777215";  -- 0x00ffffff
local strBasicBridgeTypeSetValue = "1";
local strECMBridgeTypeSetValue = "1";
local strEEMBridgeTypeSetValue = "1";
local strNCMBridgeTypeSetValue = "1";

-- values read from registry
local strNdisIfType = "";
local strSingleIn = "";
local strSingleOut = "";
local strNetLIP = "";   
local strNetMIP = ""; 
local strNetSIP = ""; 
local strNetMask = "";  
local strBasicBridgeType = "";
local strECMBridgeType = "";
local strEEMBridgeType = "";
local strNCMBridgeType = "";

if( Registry.DoesKeyExist(HKEY_LOCAL_MACHINE, strDatacardUSBLANKeyPath)) then
	
	-- Get current NdisIfType value and set to strNdisIfTypeSetValue if it is not currently set to this value.
	strNdisIfType = Registry.GetValue(HKEY_LOCAL_MACHINE, strDatacardUSBLANKeyPath, "NdisIfType");
	if (String.Length(strNdisIfType) == 0) then
		strNdisIfType = "not found";
	end
	fDebug("INFO: USBLan NdisIfType value is "..strNdisIfType);
	if (strNdisIfType ~= strNdisIfTypeSetValue) then
		Registry.SetValue(HKEY_LOCAL_MACHINE, strDatacardUSBLANKeyPath, "NdisIfType", strNdisIfTypeSetValue, REG_DWORD);
		fDebug("INFO: USBLan NdisIfType value set to "..strNdisIfTypeSetValue);
		-- Set reboot flag to make sure new setting takes effect.
		bRebootRequired = true;
	end
		
	-- Get current SingleIn and SingleOut values and set to strSingleInOutSetValue if either is not currently set to this value.
	strSingleIn = Registry.GetValue(HKEY_LOCAL_MACHINE, strDatacardUSBLANKeyPath, "SingleIn");
	strSingleOut = Registry.GetValue(HKEY_LOCAL_MACHINE, strDatacardUSBLANKeyPath, "SingleOut");
	if (String.Length(strSingleIn) == 0) then
		strSingleIn = "not found";
	end
	fDebug("INFO: USBLan SingleIn value is "..strSingleIn);
	if (String.Length(strSingleOut) == 0) then
		strSingleOut = "not found";
	end
	fDebug("INFO: USBLan SingleOut value is "..strSingleOut);
	if ((strSingleIn ~= strSingleInOutSetValue) or (strSingleOut ~= strSingleInOutSetValue)) then
		Registry.SetValue(HKEY_LOCAL_MACHINE, strDatacardUSBLANKeyPath, "SingleIn", strSingleInOutSetValue, REG_DWORD);
		Registry.SetValue(HKEY_LOCAL_MACHINE, strDatacardUSBLANKeyPath, "SingleOut", strSingleInOutSetValue, REG_DWORD);
		fDebug("INFO: USBLan SingleIn-Out values set to "..strSingleInOutSetValue);
		-- Set reboot flag to make sure new setting takes effect.
		bRebootRequired = true;
	end
	
	-- Get current NetLIP value and set to strNetLIPSetValue if it is not currently set to this value.
	strNetLIP = Registry.GetValue(HKEY_LOCAL_MACHINE, strDatacardUSBLANKeyPath, "NetworkLIP");
	if (String.Length(strNetLIP) == 0) then
		strNetLIP = "not found";
	end
	fDebug("INFO: USBLan NetworkLIP value is "..strNetLIP);
	if (strNetLIP ~= strNetLIPSetValue) then
		Registry.SetValue(HKEY_LOCAL_MACHINE, strDatacardUSBLANKeyPath, "NetworkLIP", strNetLIPSetValue, REG_DWORD);
		fDebug("INFO: USBLan NetworkLIP value set to "..strNetLIPSetValue);
		-- Set reboot flag to make sure new setting takes effect.
		bRebootRequired = true;
	end
	
	-- Get current NetMIP value and set to strNetMIPSetValue if it is not currently set to this value.
	strNetMIP = Registry.GetValue(HKEY_LOCAL_MACHINE, strDatacardUSBLANKeyPath, "NetworkMIP");
	if (String.Length(strNetMIP) == 0) then
		strNetMIP = "not found";
	end
	fDebug("INFO: USBLan NetworkMIP value is "..strNetMIP);
	if (strNetMIP ~= strNetMIPSetValue) then
		Registry.SetValue(HKEY_LOCAL_MACHINE, strDatacardUSBLANKeyPath, "NetworkMIP", strNetMIPSetValue, REG_DWORD);
		fDebug("INFO: USBLan NetworkMIP value set to "..strNetMIPSetValue);
		-- Set reboot flag to make sure new setting takes effect.
		bRebootRequired = true;
	end
	
	-- Get current NetSIP value and set to strNetSIPSetValue if it is not currently set to this value.
	strNetSIP = Registry.GetValue(HKEY_LOCAL_MACHINE, strDatacardUSBLANKeyPath, "NetworkSIP");
	if (String.Length(strNetSIP) == 0) then
		strNetSIP = "not found";
	end
	fDebug("INFO: USBLan NetworkSIP value is "..strNetSIP);
	if (strNetSIP ~= strNetSIPSetValue) then
		Registry.SetValue(HKEY_LOCAL_MACHINE, strDatacardUSBLANKeyPath, "NetworkSIP", strNetSIPSetValue, REG_DWORD);
		fDebug("INFO: USBLan NetworkSIP value set to "..strNetSIPSetValue);
		-- Set reboot flag to make sure new setting takes effect.
		bRebootRequired = true;
	end
	
	-- Get current NetMask value and set to strNetMaskSetValue if it is not currently set to this value.
	strNetMask = Registry.GetValue(HKEY_LOCAL_MACHINE, strDatacardUSBLANKeyPath, "NetworkMask");
	if (String.Length(strNetMask) == 0) then
		strNetMask = "not found";
	end
	fDebug("INFO: USBLan NetworkMask value is "..strNetMIP);
	if (strNetMask ~= strNetMaskSetValue) then
		Registry.SetValue(HKEY_LOCAL_MACHINE, strDatacardUSBLANKeyPath, "NetworkMask", strNetMaskSetValue, REG_DWORD);
		fDebug("INFO: USBLan NetworkMask value set to "..strNetMaskSetValue);
		-- Set reboot flag to make sure new setting takes effect.
		bRebootRequired = true;
	end
	
	-- Get current BasicBridgeType value and set to strBasicBridgeTypeSetValue if it is not currently set to this value.
	strBasicBridgeType = Registry.GetValue(HKEY_LOCAL_MACHINE, strDatacardUSBLANKeyPath, "BasicBridgeType");
	if (String.Length(strBasicBridgeType) == 0) then
		strBasicBridgeType = "not found";
	end
	fDebug("INFO: USBLan BasicBridgeType value is "..strBasicBridgeType);
	if (strBasicBridgeType ~= strBasicBridgeTypeSetValue) then
		Registry.SetValue(HKEY_LOCAL_MACHINE, strDatacardUSBLANKeyPath, "BasicBridgeType", strBasicBridgeTypeSetValue, REG_DWORD);
		fDebug("INFO: USBLan BasicBridgeType value set to "..strBasicBridgeTypeSetValue);
		-- Set reboot flag to make sure new setting takes effect.
		bRebootRequired = true;
	end
	
	-- Get current ECMBridgeType value and set to strECMBridgeTypeSetValue if it is not currently set to this value.
	strECMBridgeType = Registry.GetValue(HKEY_LOCAL_MACHINE, strDatacardUSBLANKeyPath, "ECMBridgeType");
	if (String.Length(strECMBridgeType) == 0) then
		strECMBridgeType = "not found";
	end
	fDebug("INFO: USBLan ECMBridgeType value is "..strECMBridgeType);
	if (strECMBridgeType ~= strECMBridgeTypeSetValue) then
		Registry.SetValue(HKEY_LOCAL_MACHINE, strDatacardUSBLANKeyPath, "ECMBridgeType", strECMBridgeTypeSetValue, REG_DWORD);
		fDebug("INFO: USBLan ECMBridgeType value set to "..strECMBridgeTypeSetValue);
		-- Set reboot flag to make sure new setting takes effect.
		bRebootRequired = true;
	end
	
	-- Get current EEMBridgeType value and set to strEEMBridgeTypeSetValue if it is not currently set to this value.
	strEEMBridgeType = Registry.GetValue(HKEY_LOCAL_MACHINE, strDatacardUSBLANKeyPath, "EEMBridgeType");
	if (String.Length(strEEMBridgeType) == 0) then
		strEEMBridgeType = "not found";
	end
	fDebug("INFO: USBLan EEMBridgeType value is "..strEEMBridgeType);
	if (strEEMBridgeType ~= strEEMBridgeTypeSetValue) then
		Registry.SetValue(HKEY_LOCAL_MACHINE, strDatacardUSBLANKeyPath, "EEMBridgeType", strEEMBridgeTypeSetValue, REG_DWORD);
		fDebug("INFO: USBLan EEMBridgeType value set to "..strEEMBridgeTypeSetValue);
		-- Set reboot flag to make sure new setting takes effect.
		bRebootRequired = true;
	end
	
	-- Get current NCMBridgeType value and set to strNCMBridgeTypeSetValue if it is not currently set to this value.
	strNCMBridgeType = Registry.GetValue(HKEY_LOCAL_MACHINE, strDatacardUSBLANKeyPath, "NCMBridgeType");
	if (String.Length(strNCMBridgeType) == 0) then
		strNCMBridgeType = "not found";
	end
	fDebug("INFO: USBLan NCMBridgeType value is "..strNCMBridgeType);
	if (strNCMBridgeType ~= strNCMBridgeTypeSetValue) then
		Registry.SetValue(HKEY_LOCAL_MACHINE, strDatacardUSBLANKeyPath, "NCMBridgeType", strNCMBridgeTypeSetValue, REG_DWORD);
		fDebug("INFO: USBLan NCMBridgeType value set to "..strNCMBridgeTypeSetValue);
		-- Set reboot flag to make sure new setting takes effect.
		bRebootRequired = true;
	end
	
else
	fDebug("INFO: DataCardUSBLan key not found in the registry. ");
end
fDebug("SUCCESS:	USBLan registry check complete...");